46#include "compressible_ops_update_kernel.cl.h"
49 void *m_x,
void *m_y,
void *m_z,
60 "update_uvw_kernel", &
err);
72 const int nb = (n + 256 - 1) / 256;
84 void *
u,
void *
v,
void *
w,
void *
E,
85 void *rho,
real gamma,
int n) {
94 "update_mxyz_p_ruvw_kernel", &
err);
110 const int nb = (n + 256 - 1) / 256;
130 "update_e_kernel", &
err);
139 const int nb = (n + 256 - 1) / 256;
159 "update_temperature_kernel", &
err);
168 const int nb = (n + 256 - 1) / 256;
179 void *dudx,
void *dudy,
void *dudz,
180 void *dvdx,
void *dvdy,
void *dvdz,
181 void *dwdx,
void *dwdy,
void *dwdz,
191 "ns_flux_prepare_kernel", &
err);
209 const int nb = (n + 256 - 1) / 256;
221 void *f_x,
void *f_y,
void *f_z,
223 void *
u,
void *
v,
void *
w,
void *B,
233 "ns_flux_finalize_kernel", &
err);
253 const int nb = (n + 256 - 1) / 256;
264 void *rho,
void *kappa,
real gamma,
int n) {
273 "ns_flux_temperature_kernel", &
err);
284 const int nb = (n + 256 - 1) / 256;
void opencl_update_uvw(void *u, void *v, void *w, void *m_x, void *m_y, void *m_z, void *rho, int n)
void opencl_ns_flux_prepare(void *div_flux, void *dissipation, void *h1, void *dudx, void *dudy, void *dudz, void *dvdx, void *dvdy, void *dvdz, void *dwdx, void *dwdy, void *dwdz, void *mu, int n)
void opencl_update_temperature(void *T, void *p, void *rho, real gamma, int n)
void opencl_update_e(void *E, void *p, void *ruvw, real gamma, int n)
void opencl_ns_flux_temperature(void *div_flux, void *h1, void *p, void *rho, void *kappa, real gamma, int n)
void opencl_ns_flux_finalize(void *visc_m_x, void *visc_m_y, void *visc_m_z, void *visc_E, void *f_x, void *f_y, void *f_z, void *opgrad_x, void *opgrad_y, void *opgrad_z, void *u, void *v, void *w, void *B, void *dissipation, int n)
void opencl_update_mxyz_p_ruvw(void *m_x, void *m_y, void *m_z, void *p, void *ruvw, void *u, void *v, void *w, void *E, void *rho, real gamma, int n)
__global__ void ale_add_kinematics_kernel(const int n, T *__restrict__ wx, T *__restrict__ wy, T *__restrict__ wz, const T *__restrict__ x_ref, const T *__restrict__ y_ref, const T *__restrict__ z_ref, const T *__restrict__ phi, const T *__restrict__ x, const T *__restrict__ y, const T *__restrict__ z, const kinematics_params_t kin_params)
__global__ void T *__restrict__ T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ w
__global__ void T *__restrict__ T *__restrict__ const T *__restrict__ u
__global__ void T *__restrict__ T *__restrict__ const T *__restrict__ const T *__restrict__ v
__global__ void T *__restrict__ T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ h1
void opencl_kernel_jit(const char *kernel, cl_program *program)
void * compressible_ops_update_program